@@ -32,11 +32,11 @@ def getbytes(
             else:
                 dump.memory = chunk
 
-            fmt = repr(dump.fmt) + " " if dump.fmt else ""
+            extra = f" {dump.fmt}" if dump.fmt else ""
 
             unpack_shortage = (
-                f"{nbytes - len(chunk)} too few bytes to unpack {fmt}"
-                f"({nbytes} needed, only {len(chunk)} available)"
+                f"{nbytes - len(chunk)} too few bytes to unpack{extra}"
+                f", {nbytes} needed, only {len(chunk)} available"
             )
 
             raise InsufficientMemoryError(unpack_shortage)
