@@ -60,7 +60,7 @@ def calcsize(fmt: ItemsFormat) -> Union[int, None]:
         raise TypeError(f"invalid format {fmt!r}")
 
     try:
-        return sum(sizes)
+        return sum(sizes)  # type: ignore
     except TypeError:
         # must be None in list indicating something variable size
         return None
