@@ -18,7 +18,7 @@ class TestPack:
     def test_cannot_convert(self):
         """Test exception when converting to decimal."""
         with pytest.raises(PackError) as trap:
-            pack("foo", DecimalX("u16p1", 2, 1, "big", signed=False))
+            pack("foo", DecimalX(2, 1, "big", signed=False, name="u16p1"))
 
         expected = Baseline(
             """
