@@ -453,7 +453,7 @@ class TestTypeFactorySingleDim(Case):
 
             def __repr__(self) -> str:
                 try:
-                    return f"{type(self).__name__}(data_type={repr(self.data_type).split(':', 1)[0][1:]}, data_len={self.data_len!r}, data={self.data!r}, bookend={self.bookend!r})"
+                    return f"{type(self).__name__}(data_type={repr(self.data_type).split(':', 1)[0].lstrip('<')}, data_len={self.data_len!r}, data={self.data!r}, bookend={self.bookend!r})"
                 except Exception:
                     return f"{type(self).__name__}()"
 
@@ -706,7 +706,7 @@ class TestTypeFactoryMultiDim(Case):
 
             def __repr__(self) -> str:
                 try:
-                    return f"{type(self).__name__}(data_type={repr(self.data_type).split(':', 1)[0][1:]}, data_dims={self.data_dims!r}, data={self.data!r}, bookend={self.bookend!r})"
+                    return f"{type(self).__name__}(data_type={repr(self.data_type).split(':', 1)[0].lstrip('<')}, data_dims={self.data_dims!r}, data={self.data!r}, bookend={self.bookend!r})"
                 except Exception:
                     return f"{type(self).__name__}()"
 
