@@ -112,46 +112,46 @@ class TestFmtArg(Case):
                 (m_datatype, m_data, m_bookend) = value
 
                 if dump is None:
-                    uint8.__pack__(m_datatype, pieces, dump)
+                    cls.datatype.fmt.__pack__(m_datatype, pieces, dump)
 
                     data_fmt = cls.data.fmt(m_datatype)
                     data_fmt.__pack__(m_data, pieces, dump)
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    datatype_dump = dump.add_record(access="datatype", fmt=uint8)
-                    uint8.__pack__(m_datatype, pieces, datatype_dump)
+                    datatype_dump = dump.add_record(access="datatype", fmt=cls.datatype.fmt)
+                    cls.datatype.fmt.__pack__(m_datatype, pieces, datatype_dump)
 
                     data_fmt = cls.data.fmt(m_datatype)
                     data_dump = dump.add_record(access="data", fmt=data_fmt)
                     data_fmt.__pack__(m_data, pieces, data_dump)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["Struct", int]:
                 structure = list.__new__(cls)
 
                 if dump is None:
-                    m_datatype, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_datatype, offset = cls.datatype.fmt.__unpack__(buffer, offset, dump)
 
                     data_fmt = cls.data.fmt(m_datatype)
                     m_data, offset = data_fmt.__unpack__(buffer, offset, dump)
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
 
                 else:
-                    datatype_dump = dump.add_record(access="datatype", fmt=uint8)
-                    m_datatype, offset = uint8.__unpack__(buffer, offset, datatype_dump)
+                    datatype_dump = dump.add_record(access="datatype", fmt=cls.datatype.fmt)
+                    m_datatype, offset = cls.datatype.fmt.__unpack__(buffer, offset, datatype_dump)
 
                     data_fmt = cls.data.fmt(m_datatype)
                     data_dump = dump.add_record(access="data", fmt=data_fmt)
                     m_data, offset = data_fmt.__unpack__(buffer, offset, data_dump)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
 
                 structure[:] = (m_datatype, m_data, m_bookend)
 
@@ -282,23 +282,23 @@ class TestMethod(Case):
                 (m_datatype, m_data, m_bookend) = value
 
                 if dump is None:
-                    uint8.__pack__(m_datatype, pieces, dump)
+                    cls.datatype.fmt.__pack__(m_datatype, pieces, dump)
 
                     data_fmt = cls.data.fmt(value)
                     data_fmt.__pack__(m_data, pieces, dump)
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    datatype_dump = dump.add_record(access="datatype", fmt=uint8)
-                    uint8.__pack__(m_datatype, pieces, datatype_dump)
+                    datatype_dump = dump.add_record(access="datatype", fmt=cls.datatype.fmt)
+                    cls.datatype.fmt.__pack__(m_datatype, pieces, datatype_dump)
 
                     data_fmt = cls.data.fmt(value)
                     data_dump = dump.add_record(access="data", fmt=data_fmt)
                     data_fmt.__pack__(m_data, pieces, data_dump)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["Struct", int]:
@@ -306,19 +306,19 @@ class TestMethod(Case):
                 add_member = structure.append
 
                 if dump is None:
-                    m_datatype, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_datatype, offset = cls.datatype.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_datatype)
 
                     data_fmt = cls.data.fmt(structure)
                     m_data, offset = data_fmt.__unpack__(buffer, offset, dump)
                     add_member(m_data)
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_bookend)
 
                 else:
-                    datatype_dump = dump.add_record(access="datatype", fmt=uint8)
-                    m_datatype, offset = uint8.__unpack__(buffer, offset, datatype_dump)
+                    datatype_dump = dump.add_record(access="datatype", fmt=cls.datatype.fmt)
+                    m_datatype, offset = cls.datatype.fmt.__unpack__(buffer, offset, datatype_dump)
                     add_member(m_datatype)
 
                     data_fmt = cls.data.fmt(structure)
@@ -326,8 +326,8 @@ class TestMethod(Case):
                     m_data, offset = data_fmt.__unpack__(buffer, offset, data_dump)
                     add_member(m_data)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
                     add_member(m_bookend)
 
                 return structure, offset
@@ -458,23 +458,23 @@ class TestProperty(Case):
                 (m_datatype, m_data, m_bookend) = value
 
                 if dump is None:
-                    uint8.__pack__(m_datatype, pieces, dump)
+                    cls.datatype.fmt.__pack__(m_datatype, pieces, dump)
 
                     data_fmt = cls.data.fmt(value)
                     data_fmt.__pack__(m_data, pieces, dump)
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    datatype_dump = dump.add_record(access="datatype", fmt=uint8)
-                    uint8.__pack__(m_datatype, pieces, datatype_dump)
+                    datatype_dump = dump.add_record(access="datatype", fmt=cls.datatype.fmt)
+                    cls.datatype.fmt.__pack__(m_datatype, pieces, datatype_dump)
 
                     data_fmt = cls.data.fmt(value)
                     data_dump = dump.add_record(access="data", fmt=data_fmt)
                     data_fmt.__pack__(m_data, pieces, data_dump)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["Struct", int]:
@@ -482,19 +482,19 @@ class TestProperty(Case):
                 add_member = structure.append
 
                 if dump is None:
-                    m_datatype, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_datatype, offset = cls.datatype.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_datatype)
 
                     data_fmt = cls.data.fmt(structure)
                     m_data, offset = data_fmt.__unpack__(buffer, offset, dump)
                     add_member(m_data)
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_bookend)
 
                 else:
-                    datatype_dump = dump.add_record(access="datatype", fmt=uint8)
-                    m_datatype, offset = uint8.__unpack__(buffer, offset, datatype_dump)
+                    datatype_dump = dump.add_record(access="datatype", fmt=cls.datatype.fmt)
+                    m_datatype, offset = cls.datatype.fmt.__unpack__(buffer, offset, datatype_dump)
                     add_member(m_datatype)
 
                     data_fmt = cls.data.fmt(structure)
@@ -502,8 +502,8 @@ class TestProperty(Case):
                     m_data, offset = data_fmt.__unpack__(buffer, offset, data_dump)
                     add_member(m_data)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
                     add_member(m_bookend)
 
                 return structure, offset
